/*

Sppong: An example of using SDL with the SDL_image and SDL_ttf libraries..
Copyright (C) 2010-2012 Issam Abdallah

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Issam Abdallah, Tunisia
iabdallah@iissam.com

*/


#include <stdlib.h>

#if defined (WIN32)
    #include <SDL.h>
    #include <SDL_ttf.h>
    #include <SDL_image.h>
#else
    #include <SDL/SDL.h>
    #include <SDL/SDL_ttf.h>
    #include <SDL/SDL_image.h>
#endif

#include "common.h"
#include "screen.h"
#include "pause.h"
#include "movball.h"


int main(int argc, char *argv[])
{

  int begin = 1;

     // initialisation of SDL
         if ( SDL_Init(SDL_INIT_TIMER | SDL_INIT_VIDEO) == -1)
          {
           fprintf(stderr, "SDL_Init Error : %s\n", SDL_GetError());
           exit(0);
          }


     // initialisation of SDL_ttf
	 if(TTF_Init() == -1)
	  {
	   fprintf(stderr, "TTF_Init Error : %s\n", TTF_GetError());
	   exit(0);
	  }


//surfaces creation

     // principal windows : screen
     screen   = SDL_SetVideoMode( width , length   ,BitPixel, SDL_HWSURFACE | SDL_DOUBLEBUF );

     // surfaces
     surface  = SDL_CreateRGBSurface(SDL_HWSURFACE, 500, 500,     BitPixel, 0, 0, 0, 0);
     table    = SDL_CreateRGBSurface(SDL_HWSURFACE, 190, 500,     BitPixel, 0, 0, 0, 0);
     center   = SDL_CreateRGBSurface(SDL_HWSURFACE, surface->w, 1,BitPixel, 0, 0, 0, 0);

     // loading images
     ball  = IMG_Load("ball.png");
     rack1 = IMG_Load("rack.png");
     rack2 = IMG_Load("rack.png");
     icon  = IMG_Load("icon.png");

        if((ball == NULL)||(rack1 == NULL)||(rack2 == NULL)||(icon == NULL))
         {
          fprintf(stderr, "image loading : %s\n", SDL_GetError());
          exit(0);
         }

     // loading fonts
     police = TTF_OpenFont("style.TTF", 25);

     policeDIG = TTF_OpenFont("DIGITAL.TTF", 30);
     policeDIG2 = TTF_OpenFont("DIGITAL.TTF", 45);

      if((police == NULL)||(policeDIG == NULL))
         {
          fprintf(stderr, "police loading : %s\n", TTF_GetError());
          exit(0);
         }


     text = TTF_RenderText_Blended(police, "PRESS ENTER !", black);

     // setting icon & caption
     SDL_WM_SetIcon(icon, NULL);
     SDL_WM_SetCaption("Sppong",NULL);

     // key repeat efter 30ms, hide mouse cursor
     SDL_EnableKeyRepeat(30, 0);
     SDL_ShowCursor(0);

     // surface
     positionSur.x = 20;
     positionSur.y = 30;

     //table
     positionTab.x = positionSur.x + surface->w + 4;
     positionTab.y = 30;

     positionRack1.x = surface->w/2 - rack1->w/2;
     positionRack1.y = surface->h - rack1->h -3;

     positionRack2.x = surface->w/2 - rack2->w/2;
     positionRack2.y =  3 + ball->h;

     positionBall.x = surface->w/2 -ball->w/2;
     positionBall.y = surface->h - rack1->h -3 -ball->h;

     position.x =  surface ->w/2 - text->w/2;
     position.y =  surface ->h/2 - text->h/2 - 8;

     center_surf.y   = surface->h/2 ;
     center_surf.x   = 0;



					 //                    width_rack
					 //                <------------------------------>
					 //
                                         // position2.x ---> _____ _____ _____ _____ _____
                                         //                 |_____|_____|_____|_____|_____| <--- rack2: "P1"
                                         //                       |     |     |     |
     limitCollision1 = 1*rack1->w/5;     //                       1     |     |     |
     limitCollision2 = 2*rack2->w/5;     //                       |     2     |     |
     limitCollision3 = 3*rack1->w/5;     //                       |     |     3     |
     limitCollision4 = 4*rack2->w/5;     //                	  |     |     |     4
                                         //                  _____|_____|_____|_____|_____
                                         //                 |_____|_____|_____|_____|_____| <--- rack1: "P2"


     tolerence1 = ball->w/2;
     tolerence2 = ball->w/2;

     limit_haut  = rack2->h + positionRack2.y;
     limit_bas   = positionRack1.y;
     limit_right = surface->w - ball->w;

     // call fonction wait
     pause(begin);


//    playing !!!!!!!!   v(^_^)v

while(play)
{


     center_ball       = positionBall.x + ball->w/2;
     width_rack2  = positionRack2.x + rack2->w;
     width_rack1  = positionRack1.x + rack1->w;

   if (positionBall.y  + ball->h == limit_bas)
   {
     begin = 1;

                     //                                  _
	             //                                _   sens == 1
	             //                              _
		     //                            _
		     //  _____ _____ _____ _____ _ _ _
		     // |_____|_____|_____|_____|_|_|_|


     if((center_ball <= width_rack1 + tolerence1)&&(center_ball > positionRack1.x + limitCollision4 ))
     sens = 1;

              	       //                         _
                       //                        _    sens == 2
		       //		        _
		       //                      _
		       //  _____ _____ _____ _ _ _ _____
		       // |_____|_____|_____|_|_|_|_____|

     if((center_ball <= positionRack1.x + limitCollision4 )&&(center_ball > positionRack1.x + limitCollision3 ))
     sens = 2;

                        //                ^
	                //                |
	                //                |
	                //  _____ _____ _ _ _ _____ _____
	                // |_____|_____|_|_|_|_____|_____|sens == 3 : vertical


     if((center_ball >= positionRack1.x + limitCollision2 )&&(center_ball <= positionRack1.x + limitCollision3))
     sens = 3;

                        //  _____ _ _ _ _____ _____ _____
                        // |_____|_|_|_|_____|_____|_____| sens == 4

     if((center_ball >= positionRack1.x + limitCollision1 )&&(center_ball < positionRack1.x +limitCollision2))
     sens = 4;

                       //  _ _ _ _____ _____ _____ _____
		       // |_|_|_|_____|_____|_____|_____| sens == 5

     if((center_ball< positionRack1.x + limitCollision1)&&(center_ball >= positionRack1.x - tolerence1))
     sens = 5;


   }


   if (positionBall.y == limit_haut)
   {
     begin = 0;


                      //    _____ _____ _____ _____ _ _ _
		      //   |_____|_____|_____|_____|_|_|_| sens == 6

     if((center_ball <= width_rack2 + tolerence2)&&(center_ball > positionRack2.x + limitCollision4))
     sens = 6;


                        //  _____ _____ _____ _ _ _ _____
			// |_____|_____|_____|_|_|_|_____| sens == 7

     if((center_ball <= positionRack2.x + limitCollision4 )&&(center_ball > positionRack2.x + limitCollision3 ))
     sens = 7;


     	    		//  _____ _____ _ _ _ _____ _____
	                // |_____|_____|_|_|_|_____|_____| sens == 8

     if((center_ball >= positionRack2.x + limitCollision2 )&&(center_ball <= positionRack2.x + limitCollision3))
     sens = 8;



                       //   _____ _ _ _ _____ _____ _____
		       //  |_____|_|_|_|_____|_____|_____| sens == 9

     if((center_ball >= positionRack2.x +limitCollision1 )&&(center_ball < positionRack2.x + limitCollision2))
     sens = 9;

	             //     _ _ _ _____ _____ _____ _____
	    	     //    |_|_|_|_____|_____|_____|_____| sens == 10


     if((center_ball< positionRack2.x + limitCollision1)&&(center_ball >= positionRack2.x -tolerence2))
     sens = 10;


   }


   // Player 1 lose

  if(positionBall.y > positionSur.y + surface->h )
  {
            // stop timer <=> stop ball
	    SDL_SetTimer(stopBall, NULL);
	    score2 ++;

	    begin = 0;

            // initialise Rackuettes position
	    positionRack1.x = surface->w/2 - rack1->w/2;
	    positionRack2.x = surface->w/2 - rack1->w/2;

	    // service return to player 2
	    positionBall.x = surface->w/2 -ball->w/2;
	    positionBall.y = ball->w + rack2->h +3;

	    free(text);

	    // display a message
	    text = TTF_RenderText_Blended(police, " CONTINUE ?", black);

            // call functions
	    display(0,100,0);
	    pause(begin);

  }

 //Player 2 lose

  if(positionBall.y  == 0)
  {

	    SDL_SetTimer(stopBall, NULL);
	    score1 ++;

	    begin = 1;

	    positionRack1.x = surface->w/2 - rack1->w/2;
	    positionRack2.x = surface->w/2 - rack1->w/2;

	    positionBall.x = surface->w/2 -ball->w/2;
	    positionBall.y = surface->h - rack1->h -3 -ball->h;

	    free(text);

	    text = TTF_RenderText_Blended(police, " CONTINUE ?", black);

	    display(0,100,0);
	    pause(begin);

  }


    //  Polling for events without interrupting the program
    SDL_PollEvent(&event);
    switch(event.type)
    {

        case SDL_MOUSEMOTION: /* if((positionRack1.x > 3)||( positionRack1.x + rack1->w < surface->w -5))
				  positionRack1.x = event.motion.x;*/

        break;

      // event = keybord keydown
        case SDL_KEYDOWN:
	                // what key ?
	                switch(event.key.keysym.sym)
		        {
			// direction key : right
			case SDLK_RIGHT :     if( width_rack1 < surface->w -5)
						 positionRack1.x += Rspeed;

		         break;
			// direction key : left
			 case SDLK_LEFT  :       if(positionRack1.x > 3)
						  positionRack1.x -= Rspeed;

                          break;

                      	 // key = 'v' : right
			 case SDLK_v    :	if( width_rack2 < surface->w - 5)
			                         positionRack2.x += Rspeed;

			  break;

	                 // key = 'x' : left
			 case SDLK_x	:	if(positionRack2.x > 3)
			                         positionRack2.x -= Rspeed;

			  break;

			 // key = echap : break game
			 case SDLK_ESCAPE:      text = TTF_RenderText_Blended(police, "       pause!    ", black);

						// Rackuette position initialisation
					        positionRack1.x = surface->w/2 - rack1->w/2;
						positionRack2.x = surface->w/2 - rack2->w/2;

			                        pause(begin);
                         break;


			 default:
			 break;
		      }


      default :
      break;
    }

   // display the game's new state
   display(0,200,0);

}
// leaving the game : liberate allocated memory

     // timer destruction
    SDL_SetTimer(stopBall, NULL);

     // liberate memory
    SDL_FreeSurface(rack1);
    SDL_FreeSurface(rack2);
    SDL_FreeSurface(ball);
    SDL_FreeSurface(surface);
    SDL_FreeSurface(scorePlayer);
    SDL_FreeSurface(P1_P2);
    SDL_FreeSurface(text);
    SDL_FreeSurface(time);
    TTF_CloseFont(police);
    TTF_Quit();
    SDL_Quit();

return EXIT_SUCCESS;
}

